@@ -1,3 +1,5 @@
+pub mod abstract_webhook_payload;
+pub use self::abstract_webhook_payload::AbstractWebhookPayload;
 pub mod alias;
 pub use self::alias::Alias;
 pub mod alias_dto;
@@ -176,8 +178,6 @@ pub mod wait_for_conditions;
 pub use self::wait_for_conditions::WaitForConditions;
 pub mod webhook_dto;
 pub use self::webhook_dto::WebhookDto;
-pub mod webhook_payload;
-pub use self::webhook_payload::WebhookPayload;
 pub mod webhook_projection;
 pub use self::webhook_projection::WebhookProjection;
 pub mod webhook_test_request;
